==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/WebPivotGridValueTemplateContextDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebPivotValueDescriptionMetadata } from "./WebPivotValueDescriptionMetadata";
import { WebPivotGridValueTemplateContextDescription } from "./WebPivotGridValueTemplateContextDescription";
/**
 * @hidden
 */
export let WebPivotGridValueTemplateContextDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebPivotGridValueTemplateContextDescriptionMetadata extends Base {
        static b(a) {
            if (WebPivotGridValueTemplateContextDescriptionMetadata.a == null) {
                WebPivotGridValueTemplateContextDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebPivotGridValueTemplateContextDescriptionMetadata.c(WebPivotGridValueTemplateContextDescriptionMetadata.a);
            }
            if (a.k(WebPivotGridValueTemplateContextDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebPivotGridValueTemplateContextDescriptionMetadata.a);
            WebPivotValueDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:PivotGridValueTemplateContext");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__isPlainObject", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Implicit", "ExportedType:WebPivotValue");
        }
        static d(a) {
            WebPivotGridValueTemplateContextDescriptionMetadata.b(a);
            a.ad("WebPivotGridValueTemplateContext", () => new WebPivotGridValueTemplateContextDescription());
            a.ac("WebPivotGridValueTemplateContext", WebPivotGridValueTemplateContextDescriptionMetadata.a);
        }
    }
    WebPivotGridValueTemplateContextDescriptionMetadata.$t = /*@__PURE__*/ markType(WebPivotGridValueTemplateContextDescriptionMetadata, 'WebPivotGridValueTemplateContextDescriptionMetadata');
    WebPivotGridValueTemplateContextDescriptionMetadata.a = null;
    return WebPivotGridValueTemplateContextDescriptionMetadata;
})();

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm2015/lib/WebPivotGridValueTemplateContextDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebPivotValueDescriptionMetadata } from "./WebPivotValueDescriptionMetadata";
import { WebPivotGridValueTemplateContextDescription } from "./WebPivotGridValueTemplateContextDescription";
/**
 * @hidden
 */
export let WebPivotGridValueTemplateContextDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebPivotGridValueTemplateContextDescriptionMetadata extends Base {
        static b(a) {
            if (WebPivotGridValueTemplateContextDescriptionMetadata.a == null) {
                WebPivotGridValueTemplateContextDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebPivotGridValueTemplateContextDescriptionMetadata.c(WebPivotGridValueTemplateContextDescriptionMetadata.a);
            }
            if (a.k(WebPivotGridValueTemplateContextDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebPivotGridValueTemplateContextDescriptionMetadata.a);
            WebPivotValueDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:PivotGridValueTemplateContext");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__marshalByValue", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Implicit", "ExportedType:WebPivotValue");
        }
        static d(a) {
            WebPivotGridValueTemplateContextDescriptionMetadata.b(a);
            a.ae("WebPivotGridValueTemplateContext", () => new WebPivotGridValueTemplateContextDescription());
            a.ad("WebPivotGridValueTemplateContext", WebPivotGridValueTemplateContextDescriptionMetadata.a);
        }
    }
    WebPivotGridValueTemplateContextDescriptionMetadata.$t = /*@__PURE__*/ markType(WebPivotGridValueTemplateContextDescriptionMetadata, 'WebPivotGridValueTemplateContextDescriptionMetadata');
    WebPivotGridValueTemplateContextDescriptionMetadata.a = null;
    return WebPivotGridValueTemplateContextDescriptionMetadata;
})();
